package de.hdm_stuttgart.mi.sd1.task1;

/**
 * <p>Handling integer ranges</p>
 */
public class C_Range {

    /**
     * <p>Displaying a range of integer values.</p>
     *
     * <p>Integer ranges being defined by [start, end] (inclusive) shall be displayed in a user friendly way:</p>
     *
     * <ul>
     *     <li>Up to a range of four all values shall be displayed.</li>
     *     <li>Starting from five values onwards only the first, second and last value shall be visible with »...«
     *     denoting intermediate values being omitted on display</li>
     * </ul>
     *
     * <p>We provide some samples:</p>
     *
     * <table class="goikTableDefaults">
     *     <caption>Display of ranges</caption>
     *     <tbody>
     *         <tr>
     *             <th>Range</th>
     *             <th>Display</th>
     *             <th>Explanation</th>
     *         </tr>
     *         <tr>
     *             <td>
     *                 <pre><code class="nohighlight">[5, 5]</code></pre>
     *             </td>
     *             <td>
     *                 <pre><code class="nohighlight">"5"</code></pre>
     *             </td>
     *             <td>Start equals end, just one value.</td>
     *         </tr>
     *         <tr>
     *             <td>
     *                 <pre><code class="nohighlight">[1, 3]</code></pre>
     *             </td>
     *             <td>
     *                 <pre><code class="nohighlight">"1, 2, 3"</code></pre>
     *             </td>
     *             <td>Less than five elements, showing all values</td>
     *         </tr>
     *         <tr>
     *             <td>
     *                 <pre><code class="nohighlight">[-2, 7]</code></pre>
     *             </td>
     *             <td>
     *                 <pre><code class="nohighlight">"-2, -1, ..., 7"</code></pre>
     *             </td>
     *             <td>More than four elements thus using dots.</td>
     *         </tr>
     *     </tbody>
     * </table>
     *
     * @param start The range's lowest value. Must be smaller than or equal to end.
     * @param end The range's highest value. Must be larger or equal to start.
     *
     * @return A range describing string.
     *
     */
    static public String displayRange(int start, int end) {

        final StringBuilder s = new StringBuilder(Integer.toString(start));
        if (3 < end - start) {
            s.append(", ").append(start + 1)
                    .append(", ..., ").append(end);
        } else {
            for (int i = start + 1; i <= end; i++) {
                s.append(", ").append(Integer.toString(i));
            }
        }
        return s.toString();
    }
    private C_Range(){/* Ignore me: My sole purpose is suppressing default constructor javadoc generation */}
}
